@@ -138,11 +138,11 @@ pref("media.enforce_same_site_origin", false);
 // Media cache size in kilobytes
 pref("media.cache_size", 51200);
 
-//@line 142 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 142 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 pref("media.ogg.enabled", true);
-//@line 145 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 145 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 pref("media.wave.enabled", true);
-//@line 147 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 147 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
 // Whether to autostart a media element with an |autoplay| attribute
 pref("media.autoplay.enabled", true);
@@ -155,14 +155,14 @@ pref("gfx.color_management.rendering_intent", 0);
 
 pref("gfx.downloadable_fonts.enabled", true);
 pref("gfx.downloadable_fonts.sanitize", true);
-//@line 162 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 162 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 pref("gfx.downloadable_fonts.sanitize.preserve_otl_tables", true);
-//@line 164 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 164 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
-//@line 169 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 169 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -175,7 +175,7 @@ pref("accessibility.tabfocus_applies_to_xul", false);
 // unless this preference was set manually
 pref("ui.scrollToClick", 0);
 
-//@line 185 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 185 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -523,9 +523,9 @@ pref("dom.storage.default_quota",      5120);
 
 // Parsing perf prefs. For now just mimic what the old code did.
 pref("content.sink.event_probe_rate", 3);
-//@line 533 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 533 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 535 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 535 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -570,7 +570,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 582 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 582 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -701,6 +701,7 @@ pref("network.IDN.whitelist.es", true);
 pref("network.IDN.whitelist.fi", true);
 pref("network.IDN.whitelist.gr", true);
 pref("network.IDN.whitelist.hu", true);
+pref("network.IDN.whitelist.il", true);
 pref("network.IDN.whitelist.io", true);
 pref("network.IDN.whitelist.ir", true);
 pref("network.IDN.whitelist.is", true);
@@ -734,6 +735,8 @@ pref("network.IDN.whitelist.xn--mgba3a4f16a", true);
 pref("network.IDN.whitelist.xn--mgba3a4fra", true);
 // jo, Jordan, .<Al-Ordon>
 pref("network.IDN.whitelist.xn--mgbayh7gpa", true);
+// qa, Qatar, .<Qatar>
+pref("network.IDN.whitelist.xn--wgbl6a", true);
 // ru, Russian Federation, .<RF>
 pref("network.IDN.whitelist.xn--p1ai", true);
 // sa, Saudi Arabia, .<al-Saudiah> with variants
@@ -831,7 +834,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 848 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 851 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -850,9 +853,9 @@ pref("network.ntlm.send-lm-response", false);
 
 pref("permissions.default.image",           1); // 1-Accept, 2-Deny, 3-dontAcceptForeign
 
-//@line 868 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 871 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 pref("network.proxy.type",                  5);
-//@line 875 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 878 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
 pref("network.proxy.ftp",                   "");
 pref("network.proxy.ftp_port",              0);
@@ -1214,15 +1217,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1615 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1618 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2032 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2035 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2233 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2236 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2327 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2330 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2330 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2333 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1490,15 +1493,15 @@ pref("print.postscript.print_command", "lpr ${MOZ_PRINTER_NAME:+-P\"$MOZ_PRINTER
 // So, we have no reasons we should use non-toplevel window for popup.
 pref("ui.panel.default_level_parent", true);
 
-//@line 2600 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2603 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2668 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2671 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2694 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2697 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2714 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2717 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2722 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2725 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1522,7 +1525,7 @@ pref("image.cache.size", 5242880);
 // Size is given a weight of 1000 - timeweight.
 pref("image.cache.timeweight", 500);
 
-//@line 2751 "/builds/slave/mozilla-1.9.1-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2754 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
